Iideo class

Annotations
  • @collection

Constructors

Iideo({required String id, required String videoUrl, String? coverUrl, String? name, required int createdAt, IoaderStatus status = IoaderStatus.pending, I3u8? i3u8, int? total, int? received, int? lastUpdateAt})

Properties

coverUrl String?
封面原始url
getter/setter pair
createdAt int
创建时间/ms
latefinal
hashCode int
The hash code for this object.
no setterinherited
i3u8 ↔ I3u8?
m3u8信息
getter/setter pair
id String
视频唯一id
latefinal
isarId → Id
no setter
lastUpdateAt int?
最后更新时间/ms
getter/setter pair
name String?
名称
getter/setter pair
received int?
已获取文件大小
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status IoaderStatus
文件状态
getter/setter pair
total int?
文件总大小
getter/setter pair
videoUrl String
视频原始url
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited